from django import template

register = template.Library()


@register.filter(name='has_group')
def has_group(user, group_name):
    return user.groups.filter(name=group_name).exists()


@register.filter(name='in_groups')
def in_groups(user, groups_target):
    for g in user.groups.all():
        return g in groups_target.all()
    return False



from db.models import Message
from web.forms import ModelForm


class MemberForm(ModelForm):
    class Meta:
        model = Message
        fields = [
            "subject",
            "content",
        ]



from .___form import Form
from .___model_form import ModelForm
from .___multi_form import MultiForm
from .__contact_form import ContactForm
from .__control_center_form import ControlCenterChangePasswordForm, ControlCenterChangeEmailForm
from .__login_form import LoginForm
from .__logout_form import LogoutForm
from .__preferences_form import PreferencesNotificationsForm, PreferencesGeneralForm
from .__profile_form import ProfileGeneralInformationForm
from .__register_form import RegisterForm
from ._admonition_form import AdmonitionForm
from ._admonition_action_form import AdmonitionActionForm
from ._admonition_template_form import AdmonitionTemplateForm
from ._contest_form import ContestForm
from ._license_form import LicenseForm
from ._comment_form import CommentForm
from ._faq_form import FaqForm
from ._theme_selector_form import ThemeSelectorForm
from ._member_form import MemberForm
from ._post_form import PostForm
from ._site_param_form import SiteParamForm
from ._tag_form import TagForm



from django import forms
from django.utils.translation import gettext_lazy as _

from web.forms import MultiForm
from web.forms.widgets import PasswordInput, EmailInput


class ControlCenterChangePasswordForm(MultiForm):
    password = forms.CharField(
        max_length=30,
        widget=PasswordInput(
            attrs={'placeholder': _('Password')}),
        label=_('Password'))
    passwordRepeat = forms.CharField(
        max_length=30,
        widget=PasswordInput(
            attrs={'placeholder': _('Repeat your password')}),
        label=_('Repeat your password'))

    def change_password(self):
        pass


class ControlCenterChangeEmailForm(MultiForm):
    email = forms.EmailField(
        max_length=100,
        widget=EmailInput(
            attrs={'placeholder': _('Email')}),
        label=_('Email'))
    emailRepeat = forms.EmailField(
        max_length=100,
        widget=EmailInput(
            attrs={'placeholder': _('Repeat your email')}),
        label=_('Repeat your email'))

    def change_email(self):
        pass
